@@ -316,10 +316,10 @@ class DigitalObjectService(ApiMethods):
     def get_files_from_download_request(self):
 
         response = self.get_my_requests()
-        requests_ready = list(filter(lambda x: x.is_ready, response.items))
+        requests_ready = list(filter(lambda x: x.is_ready == True, response.items))
 
         for request in requests_ready:
             api_url = f'/File/DownloadRequestSet?requestId={request.id}'
-            response = self.get_data(url=api_url,request=None)           
+            response = self.download_file(url=api_url)           
 
         
\ No newline at end of file
